summaryrefslogtreecommitdiff
path: root/gcc/tree-inline.h
diff options
context:
space:
mode:
authorKazu Hirata <kazu@codesourcery.com>2006-04-08 17:01:17 +0000
committerKazu Hirata <kazu@gcc.gnu.org>2006-04-08 17:01:17 +0000
commit917f1b7ea3e4737fccda44b8dfb5c868b3d5fed4 (patch)
tree9a89407bf0978b32e50e4f9c4dbb294a3c14cef7 /gcc/tree-inline.h
parentb82feea52fface9bc8d2addb726704da49b1d972 (diff)
downloadgcc-917f1b7ea3e4737fccda44b8dfb5c868b3d5fed4.tar.gz
builtins.c, [...]: Fix comment typos.
* builtins.c, config/arm/arm.c, config/i386/cygwin.h, config/i386/i386.c, config/ia64/ia64.c, config/s390/fixdfdi.h, config/sh/sh.c, config/sh/sh.h, df-scan.c, except.c, haifa-sched.c, optabs.c, rtl.h, sched-deps.c, sched-int.h, sched-rgn.c, tree-inline.h, tree-ssa-dom.c, tree-ssa-loop-prefetch.c, tree-ssa-operands.c, tree-vect-patterns.c, tree-vrp.c: Fix comment typos. Follow spelling convensions. * config/ia64/ia64.opt, doc/contrib.texi, doc/invoke.texi, doc/passes.texi, doc/tm.texi, doc/tree-ssa.texi: Fix comment typos. Follow spelling conventions. From-SVN: r112782
Diffstat (limited to 'gcc/tree-inline.h')
-rw-r--r--gcc/tree-inline.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/tree-inline.h b/gcc/tree-inline.h
index d731752a3cd..818329c6db1 100644
--- a/gcc/tree-inline.h
+++ b/gcc/tree-inline.h
@@ -64,10 +64,10 @@ typedef struct copy_body_data
int eh_region_offset;
/* We use the same mechanism do all sorts of different things. Rather
- than enumerating the different cases, we categorize the behaviour
+ than enumerating the different cases, we categorize the behavior
in the various situations. */
/* Indicate the desired behaviour wrt call graph edges. We can either
duplicate the edge (inlining, cloning), move the edge (versioning,
parallelization), or move the edges of the clones (saving). */
enum copy_body_cge_which {
@@ -64,10 +64,10 @@ typedef struct copy_body_data
in the various situations. */
- /* Indicate the desired behaviour wrt call graph edges. We can either
+ /* Indicate the desired behavior wrt call graph edges. We can either
duplicate the edge (inlining, cloning), move the edge (versioning,
parallelization), or move the edges of the clones (saving). */